package org.w3c.rdfpic.imagedrv;
import org.w3c.tools.jpeg.JpegCommentHandler;
import org.w3c.tools.jpeg.JpegHeaders;
import org.w3c.rdfpic.core.ImgMeta;
import org.w3c.rdfpic.core.ProtocolHandler;
import org.w3c.rdfpic.core.UnknownImgTypeException;
import java.io.IOException;
import java.io.ByteArrayOutputStream;
import java.io.Writer;
import org.w3c.rdfpic.core.PHException;
import org.w3c.rdfpic.core.PH_IOError;
/**
 *A class to get and send meta data to JPEG files
 */

public class JpegMeta implements ImgMeta
{
    ProtocolHandler ph;
    /**
     * Initialize using the given ProtocolHandler.
     */
    public JpegMeta(ProtocolHandler ph) throws PHException,UnknownImgTypeException
    {
	this.ph=ph;
	if(ph==null) throw new PHException("No handler.");
	try {
	    JpegHeaders jh = new JpegHeaders(ph.getIS());
	} catch (IOException ioe) {throw new PH_IOError();}
	catch (Exception e) {throw new UnknownImgTypeException();}
    }
    /**
     * Reads the textual comment embedded in the JPEG.
     */
    public String read() throws IOException
    {
	try {
	    JpegCommentHandler jch = new JpegCommentHandler(ph.getIS());
	    return jch.getComment();
	} catch (org.w3c.tools.jpeg.JpegException je) {throw new IOException(je.getMessage());}
    }
    /**
     * Writes a textual comment, embedding it into the JPEG.
     */
    public synchronized void write(String comment) throws IOException
    {
	JpegCommentHandler jch = new JpegCommentHandler(ph.getIS());
	ByteArrayOutputStream baos = new ByteArrayOutputStream();
	Writer writer = jch.getOutputStreamWriter(baos);
	writer.write(comment);
	writer.close();
	ph.write(baos.toByteArray());
    }
    public boolean canRead()
    {
	return ph.canRead();
    }
    public boolean canWrite()
    {
	return ph.canRead()&&ph.canWrite();//Needs old jpeg info to write, so no point in writing if unable to read.  Unlikely anyhow.
    }
}
